const assert = require('assert');
const { When, Then } = require('@cucumber/cucumber');

const { fixtures } = require('../../fixtures/server');

const mockValidConfig = fixtures.get('config-valid');

When('a mock send API response is configured to return success', function () {
  const response = {};
  this.mockAxios.onPost(`${mockValidConfig.api}/send`).reply(200, response);
});

When(
  'a mock send API response is configured to return a {int} error',
  function (statusCode) {
    const statusMessages = {
      403: 'Token expired',
      503: 'Service unavailable',
    };
    this.mockAxios
      .onPost(`${mockValidConfig.api}/send`)
      .reply(statusCode, { message: statusMessages[statusCode] });
  }
);

When('the publish method is called', function () {
  const message = fixtures.get('message-vehicle-status');
  this.message = message;
  const topic = message.metadata.destination;
  const body = JSON.stringify(message);
  this.call = this.adapter.publish(topic, body);
  this.callCounts.publish = this.adapter.getTrackedCalls('publish').length;
});

When('the publish method is called with is_retry on', function () {
  const message = fixtures.get('message-vehicle-status');
  this.message = message;
  const topic = message.metadata.destination;
  const body = JSON.stringify(message);
  this.call = this.adapter.publish(topic, body, true);
  this.callCounts.publish = this.adapter.getTrackedCalls('publish').length;
});

Then('the publish method was called with is_retry on', function () {
  let publishCalls = this.adapter.getTrackedCalls('publish');
  let lastCall = publishCalls[publishCalls.length - 1];
  assert.ok(lastCall.arguments[1].is_retry);
});

Then('the publish method is not called again', function () {
  let newPublishCallCount = this.adapter.getTrackedCalls('publish').length;
  assert.equal(this.callCounts.publish, newPublishCallCount);
});
